@@ -54,7 +54,8 @@ class TestPluginCanHandleUrlUStreamTV(PluginCanHandleUrl):
 
 class TestPluginUStreamTV:
     def test_arguments(self):
-        from streamlink_cli.main import setup_plugin_args
+        from streamlink_cli.main import setup_plugin_args  # noqa: PLC0415
+
         session = Streamlink()
         parser = MagicMock()
         plugins = parser.add_argument_group("Plugin Options")
